@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Play the tabla!
 
-our $VERSION = '0.0502';
+our $VERSION = '0.0600';
 
 use Moo;
 use File::ShareDir qw(dist_dir);
@@ -76,6 +76,77 @@ sub double_strike {
     $self->note($dura, $baya, $daya);
 }
 
+
+sub teentaal {
+    my ($self, $dura) = @_;
+    $dura ||= $self->quarter;
+    for (1 .. 2) {
+        $self->double_strike('dha', $dura);
+        $self->double_strike('dhin', $dura);
+        $self->double_strike('dhin', $dura);
+        $self->double_strike('dha', $dura);
+    }
+    $self->double_strike('dha', $dura);
+    $self->strike('tin', $dura);
+    $self->strike('tin', $dura);
+    $self->strike('ta', $dura);
+    $self->strike('ta', $dura);
+    $self->double_strike('dhin', $dura);
+    $self->double_strike('dhin', $dura);
+    $self->double_strike('dha', $dura);
+}
+
+sub keherawa {
+    my ($self, $dura) = @_;
+    $dura ||= $self->quarter;
+    $self->double_strike('dha', $dura);
+    $self->strike('ge', $dura);
+    $self->strike('na', $dura);
+    $self->strike('tin', $dura);
+    $self->strike('na', $dura);
+    $self->strike('ke', $dura);
+    $self->double_strike('dhin', $dura);
+    $self->strike('na', $dura);
+}
+
+sub jhaptaal {
+    my ($self, $dura) = @_;
+    $dura ||= $self->quarter;
+    $self->double_strike('dhin', $dura);
+    $self->strike('na', $dura);
+    $self->double_strike('dhin', $dura);
+    $self->double_strike('dhin', $dura);
+    $self->strike('na', $dura);
+    $self->strike('tin', $dura);
+    $self->strike('na', $dura);
+    $self->double_strike('dhin', $dura);
+    $self->double_strike('dhin', $dura);
+    $self->strike('na', $dura);
+}
+
+sub dadra {
+    my ($self, $dura) = @_;
+    $dura ||= $self->quarter;
+    $self->double_strike('dha', $dura);
+    $self->double_strike('dhin', $dura);
+    $self->strike('na', $dura);
+    $self->double_strike('dha', $dura);
+    $self->strike('ti', $dura);
+    $self->strike('na', $dura);
+}
+
+sub rupaktaal {
+    my ($self, $dura) = @_;
+    $dura ||= $self->quarter;
+    $self->strike('tin', $dura);
+    $self->strike('tin', $dura);
+    $self->strike('na', $dura);
+    $self->double_strike('dhin', $dura);
+    $self->strike('na', $dura);
+    $self->double_strike('dhin', $dura);
+    $self->strike('na', $dura);
+}
+
 1;
 
 __END__
@@ -90,7 +161,7 @@ Music::Percussion::Tabla - Play the tabla!
 
 =head1 VERSION
 
-version 0.0502
+version 0.0600
 
 =head1 SYNOPSIS
 
@@ -109,8 +180,15 @@ version 0.0502
     $t->strike('ge');
     $t->rest($t->quarter);
   }
+
   $t->double_strike('dha', $t->quarter);
 
+  $t->teentaal($t->eighth) for 1 .. $t->bars;
+  $t->keherawa($t->eighth) for 1 .. $t->bars;
+  $t->jhaptaal($t->eighth) for 1 .. $t->bars;
+  $t->dadra($t->eighth) for 1 .. $t->bars;
+  $t->rupaktaal($t->eighth) for 1 .. $t->bars;
+
   $t->play_with_timidity;
   # OR:
   $t->write; # save the score as a MIDI file
@@ -235,6 +313,22 @@ If the individual bols comprising the double-strike have more than one
 possible patch, one is chosen at random. If specific patches are
 desired, use the C<note> method with multiple patches.
 
+=head2 thekas
+
+=over
+
+=item teentaal([$duration])
+
+=item keherawa([$duration])
+
+=item jhaptaal([$duration])
+
+=item dadra([$duration])
+
+=item rupaktaal([$duration])
+
+=back
+
 =head1 SEE ALSO
 
 The F<t/01-methods.t> and F<eg/*> programs in this distribution.
